@@ -33,6 +33,23 @@ def parse_content_html(html_path):
 
 
 def extract_content(html= None, url=None):
+
+    """
+    
+    Parse content using modified version of the newsfetch library.
+
+    Args:
+        html (str): A path to an HTML file on disk to parse
+        url (str): The actual webpage link 
+    
+    Returns:
+
+        dict: Parsed results from newsfetch.newspaper.
+    
+    """
+
+
+
     if url is None:
         fetched = parse_content_html(html)
     else:
